==> apache-wicket-7.18.0.zip: apache-wicket-7.18.0/wicket-core/src/test/java/org/apache/wicket/markup/html/internal/AjaxEnclosurePage_4.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.markup.html.internal;

import org.apache.wicket.ajax.AjaxRequestTarget;
import org.apache.wicket.ajax.markup.html.form.AjaxButton;
import org.apache.wicket.ajax.markup.html.form.AjaxSubmitLink;
import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.TextField;
import org.apache.wicket.model.PropertyModel;


/**
 * Mock page for testing.
 * 
 * @author Igor Vaynberg
 * 
 */
public class AjaxEnclosurePage_4 extends WebPage
{
	private static final long serialVersionUID = 1L;

	//final Label nameLabel;
	final TextField<String> nameField;
	final AjaxSubmitLink submit;
	
	private String name;
	
	/**
	 * Construct.
	 */
	public AjaxEnclosurePage_4()
	{

		Form<?> form=new Form<Void>("form");
		queue(form);
		
		//nameLabel=new Label("nameLabel", "Name");
		//queue(nameLabel);
		
		nameField=new TextField<String>("nameField", new PropertyModel<String>(this, "name"));
		nameField.setOutputMarkupId(true);
		queue(nameField);

		submit=new AjaxSubmitLink("submit") {
			@Override
			protected void onSubmit(AjaxRequestTarget target, Form<?> form) {
				name="submitted";
				nameField.clearInput();
				target.add(nameField);
			}
		};
		queue(submit);
		
	}



}

==> apache-wicket-9.22.0.zip: apache-wicket-9.22.0/wicket-core/src/test/java/org/apache/wicket/markup/html/internal/AjaxEnclosurePage_4.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.markup.html.internal;

import org.apache.wicket.ajax.AjaxRequestTarget;
import org.apache.wicket.ajax.markup.html.form.AjaxButton;
import org.apache.wicket.ajax.markup.html.form.AjaxSubmitLink;
import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.TextField;
import org.apache.wicket.model.PropertyModel;


/**
 * Mock page for testing.
 * 
 * @author Igor Vaynberg
 * 
 */
public class AjaxEnclosurePage_4 extends WebPage
{
	private static final long serialVersionUID = 1L;

	//final Label nameLabel;
	final TextField<String> nameField;
	final AjaxSubmitLink submit;
	
	private String name;
	
	/**
	 * Construct.
	 */
	public AjaxEnclosurePage_4()
	{

		Form<?> form=new Form<Void>("form");
		queue(form);
		
		//nameLabel=new Label("nameLabel", "Name");
		//queue(nameLabel);
		
		nameField=new TextField<String>("nameField", new PropertyModel<String>(this, "name"));
		nameField.setOutputMarkupId(true);
		queue(nameField);

		submit=new AjaxSubmitLink("submit") {
			@Override
			protected void onSubmit(AjaxRequestTarget target) {
				name="submitted";
				nameField.clearInput();
				target.add(nameField);
			}
		};
		queue(submit);
		
	}



}
